@@ -292,9 +292,14 @@ pub fn get_keys() -> Keys {
                     pressed.special.backspace = true;
                     pressed.mods.alt = true;
                 },
+                // I change it to \n because that's more intuitive(at least in my opinion)
+                | Some(b'\r') | Some(b'\n') => {
+                    pressed.letter = Some('\n');
+                    pressed.mods.alt = true;
+                },
                 | Some(byte @ _) => {
                     pressed.mods.alt = true;
-                    pressed.letter = (byte as char).to_ascii_lowercase();
+                    pressed.letter = Some((byte as char).to_ascii_lowercase());
                     if byte == byte.to_ascii_uppercase() {
                         pressed.mods.shift = true;
                     }
@@ -303,35 +308,35 @@ pub fn get_keys() -> Keys {
             },
             | _ => {
                 match byte {
-                    | b'0' => pressed.letter = '0',
-                    | b'1' => pressed.letter = '1',
-                    | b'2' => pressed.letter = '2',
-                    | b'3' => pressed.letter = '3',
-                    | b'4' => pressed.letter = '4',
-                    | b'5' => pressed.letter = '5',
-                    | b'6' => pressed.letter = '6',
-                    | b'7' => pressed.letter = '7',
-                    | b'8' => pressed.letter = '8',
-                    | b'9' => pressed.letter = '9',
+                    | b'0' => pressed.letter = Some('0'),
+                    | b'1' => pressed.letter = Some('1'),
+                    | b'2' => pressed.letter = Some('2'),
+                    | b'3' => pressed.letter = Some('3'),
+                    | b'4' => pressed.letter = Some('4'),
+                    | b'5' => pressed.letter = Some('5'),
+                    | b'6' => pressed.letter = Some('6'),
+                    | b'7' => pressed.letter = Some('7'),
+                    | b'8' => pressed.letter = Some('8'),
+                    | b'9' => pressed.letter = Some('9'),
                     // I change it to \n because that's more intuitive(at least in my opinion)
-                    | b'\r' | b'\n' => pressed.letter = '\n',
-                    | b'\t' => pressed.letter = '\t',
+                    | b'\r' | b'\n' => pressed.letter = Some('\n'),
+                    | b'\t' => pressed.letter = Some('\t'),
                     | _ => match byte {
                         | b' ' ..= b'~' => {
-                            pressed.letter = byte.to_ascii_lowercase() as char;
+                            pressed.letter = Some(byte.to_ascii_lowercase() as char);
                             if byte == byte.to_ascii_uppercase() {
                                 pressed.mods.shift = true;
                             }
                         },
                         | b'\x7f' => pressed.special.backspace = true,
                         | b'\x00' .. b'\x1c' => {
-                            pressed.letter = (byte + 96) as char;
+                            pressed.letter = Some((byte + 96) as char);
                             pressed.mods.ctrl = true;
                             // This may not be true but it's not case sensitive
                             pressed.mods.shift = true;
                         },
                         | b'\x1c' ..= b'\x1f' => {
-                            pressed.letter = (byte + 64) as char;
+                            pressed.letter = Some((byte + 64) as char);
                             pressed.mods.ctrl = true;
                             // This may not be true but it's not case sensitive
                             pressed.mods.shift = true;
@@ -346,15 +351,15 @@ pub fn get_keys() -> Keys {
     pressed
 }
 
-#[derive(Default)]
+#[derive(Clone, Default)]
 pub struct Keys {
     pub mods:     Mods,
     pub movement: ArrowKeys,
-    pub letter:   char,
+    pub letter:   Option<char>,
     pub special:  Special
 }
 
-#[derive(Default)]
+#[derive(Clone, Default)]
 pub struct Mods {
     pub super_: bool,
     pub shift:  bool,
@@ -362,7 +367,7 @@ pub struct Mods {
     pub alt:    bool
 }
 
-#[derive(Default)]
+#[derive(Clone, Default)]
 pub struct ArrowKeys {
     pub right: bool,
     pub left:  bool,
@@ -370,7 +375,7 @@ pub struct ArrowKeys {
     pub down:  bool
 }
 
-#[derive(Default)]
+#[derive(Clone, Default)]
 pub struct Special {
     pub function:  Option<u8>,
     pub escape:    bool,
